package com.ruoyi.rocketmq.service;

import com.ruoyi.rocketmq.domain.InitialSwitchOpticalModule;

import java.util.List;
import java.util.Map;

/**
 * 光模块信息Service接口
 * 
 * @author gyt
 * @date 2025-09-22
 */
public interface IInitialSwitchOpticalModuleService 
{
    /**
     * 查询光模块信息
     * 
     * @param id 光模块信息主键
     * @return 光模块信息
     */
    public InitialSwitchOpticalModule selectInitialSwitchOpticalModuleById(Long id);

    /**
     * 查询光模块信息列表
     * 
     * @param initialSwitchOpticalModule 光模块信息
     * @return 光模块信息集合
     */
    public List<InitialSwitchOpticalModule> selectInitialSwitchOpticalModuleList(InitialSwitchOpticalModule initialSwitchOpticalModule);

    /**
     * 新增光模块信息
     * 
     * @param initialSwitchOpticalModule 光模块信息
     * @return 结果
     */
    public int insertInitialSwitchOpticalModule(InitialSwitchOpticalModule initialSwitchOpticalModule);

    /**
     * 修改光模块信息
     * 
     * @param initialSwitchOpticalModule 光模块信息
     * @return 结果
     */
    public int updateInitialSwitchOpticalModule(InitialSwitchOpticalModule initialSwitchOpticalModule);

    /**
     * 批量删除光模块信息
     * 
     * @param ids 需要删除的光模块信息主键集合
     * @return 结果
     */
    public int deleteInitialSwitchOpticalModuleByIds(Long[] ids);

    /**
     * 删除光模块信息信息
     * 
     * @param id 光模块信息主键
     * @return 结果
     */
    public int deleteInitialSwitchOpticalModuleById(Long id);

    /**
     * 批量插入光模块信息
     * @param list
     */
    int batchInitialSwitchOpticalModule(List<InitialSwitchOpticalModule> list);

    /**
     * 光模块基础信息
     * @param initialSwitchOpticalModule
     * @return
     */
    List<InitialSwitchOpticalModule> switchOpticalModuleMsg(InitialSwitchOpticalModule initialSwitchOpticalModule);

    /**
     * 光模块名称查询
     * @param initialSwitchOpticalModule
     * @return
     */
    List<Map> getAllModuleName(InitialSwitchOpticalModule initialSwitchOpticalModule);

    /**
     * 光衰阈值
     * @param initialSwitchOpticalModule
     * @return
     */
    Map<String, Object> opticalModuleLowThreshold(InitialSwitchOpticalModule initialSwitchOpticalModule);

    /**
     * 功率
     * @param initialSwitchOpticalModule
     * @return
     */
    Map<String, Object> opticalModulePower(InitialSwitchOpticalModule initialSwitchOpticalModule);
}
